@@ -4,6 +4,7 @@ import (
 	"github.com/spf13/cobra"
 	cmdGenerate "gitlab.com/gitlab-org/cli/commands/auth/generate"
 	authLoginCmd "gitlab.com/gitlab-org/cli/commands/auth/login"
+	authLogoutCmd "gitlab.com/gitlab-org/cli/commands/auth/logout"
 	authStatusCmd "gitlab.com/gitlab-org/cli/commands/auth/status"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
@@ -18,6 +19,7 @@ func NewCmdAuth(f *cmdutils.Factory) *cobra.Command {
 	cmd.AddCommand(authStatusCmd.NewCmdStatus(f, nil))
 	cmd.AddCommand(authLoginCmd.NewCmdCredential(f, nil))
 	cmd.AddCommand(cmdGenerate.NewCmdGenerate(f))
+	cmd.AddCommand(authLogoutCmd.NewCmdLogout(f))
 
 	return cmd
 }
