@@ -1,4 +1,4 @@
-package ci
+package artifact
 
 import (
 	"github.com/MakeNowJust/heredoc/v2"
@@ -10,12 +10,13 @@ import (
 func NewCmdRun(f *cmdutils.Factory) *cobra.Command {
 	jobArtifactCmd := &cobra.Command{
 		Use:     "artifact <refName> <jobName> [flags]",
-		Short:   `Download all artifacts from the last pipeline`,
+		Short:   `Download all artifacts from the last pipeline.`,
 		Aliases: []string{"push"},
 		Example: heredoc.Doc(`
-	glab ci artifact main build
-	glab ci artifact main deploy --path="artifacts/"
-	`),
+			# Download all artifacts from the main branch and build job
+			$ glab ci artifact main build
+			$ glab ci artifact main deploy --path="artifacts/"
+		`),
 		Long: ``,
 		Args: cobra.ExactArgs(2),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -34,9 +35,9 @@ func NewCmdRun(f *cmdutils.Factory) *cobra.Command {
 
 			return jobArtifact.DownloadArtifacts(apiClient, repo, path, args[0], args[1])
 		},
-		Deprecated: "please use 'glab job artifact' instead",
+		Deprecated: "use 'glab job artifact' instead.",
 	}
-	jobArtifactCmd.Flags().StringP("path", "p", "./", "Path to download the artifact files")
+	jobArtifactCmd.Flags().StringP("path", "p", "./", "Path to download the artifact files.")
 
 	return jobArtifactCmd
 }
