@@ -18,13 +18,11 @@ func NewCmdConfigCompile(f *cmdutils.Factory) *cobra.Command {
 		Short: "View the fully expanded CI/CD configuration.",
 		Args:  cobra.MaximumNArgs(1),
 		Example: heredoc.Doc(`
-		# Uses .gitlab-ci.yml in the current directory
-		$ glab ci config compile
-
-		$ glab ci config compile .gitlab-ci.yml
-
-		$ glab ci config compile path/to/.gitlab-ci.yml
-	`),
+			# Uses .gitlab-ci.yml in the current directory
+			$ glab ci config compile
+			$ glab ci config compile .gitlab-ci.yml
+			$ glab ci config compile path/to/.gitlab-ci.yml
+		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			path := ".gitlab-ci.yml"
 			if len(args) == 1 {
@@ -64,7 +62,7 @@ func compileRun(f *cmdutils.Factory, path string) error {
 
 	content, err := os.ReadFile(path)
 	if err != nil {
-		return fmt.Errorf("reading ci config at %s: %w", path, err)
+		return fmt.Errorf("reading CI/CD configuration at %s: %w", path, err)
 	}
 
 	compiledResult, err := api.ProjectNamespaceLint(apiClient, project.ID, string(content), "", false, false)
