@@ -71,8 +71,9 @@ func TestCiList(t *testing.T) {
 	out = timeRE.ReplaceAllString(out, "X years")
 
 	assert.Equal(t, heredoc.Doc(`
-		Showing 2 pipelines on OWNER/REPO (Page 1)
+		Showing 2 pipelines on OWNER/REPO. (Page 1)
 
+		State	IID	Ref	Created
 		(success) • #1	(#3)	refs/merge-requests/1107/merge	(about X years ago)
 		(success) • #2	(#4)	main	(about X years ago)
 
