@@ -71,14 +71,14 @@ func NewCmdRun(f *cmdutils.Factory) *cobra.Command {
 		Short:   `Create or run a new CI/CD pipeline.`,
 		Aliases: []string{"create"},
 		Example: heredoc.Doc(`
-	glab ci run
-	glab ci run --variables \"key1:value,with,comma\"
-	glab ci run -b main
-	glab ci run -b main --variables-env key1:val1
-	glab ci run -b main --variables-env key1:val1,key2:val2
-	glab ci run -b main --variables-env key1:val1 --variables-env key2:val2
-	glab ci run -b main --variables-file MYKEY:file1 --variables KEY2:some_value
-	`),
+			$ glab ci run
+			$ glab ci run --variables \"key1:value,with,comma\"
+			$ glab ci run -b main
+			$ glab ci run -b main --variables-env key1:val1
+			$ glab ci run -b main --variables-env key1:val1,key2:val2
+			$ glab ci run -b main --variables-env key1:val1 --variables-env key2:val2
+			$ glab ci run -b main --variables-file MYKEY:file1 --variables KEY2:some_value
+		`),
 		Long: ``,
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -100,7 +100,7 @@ func NewCmdRun(f *cmdutils.Factory) *cobra.Command {
 				for _, v := range customPipelineVars {
 					pvar, err := extractEnvVar(v)
 					if err != nil {
-						return fmt.Errorf("parsing pipeline variable expected format KEY:VALUE: %w", err)
+						return fmt.Errorf("parsing pipeline variable. Expected format KEY:VALUE: %w", err)
 					}
 					pipelineVars = append(pipelineVars, pvar)
 				}
