@@ -6,13 +6,13 @@ import (
 	"io"
 	"os"
 	"path/filepath"
-	"sort"
+	"slices"
 	"strconv"
 	"strings"
 
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/utils"
@@ -90,7 +90,7 @@ func ListGitLabTemplates(tmplType string) ([]string, error) {
 		}
 		files = append(files, strings.TrimSuffix(file, ".md"))
 	}
-	sort.Slice(files, func(i, j int) bool { return files[i] < files[j] })
+	slices.Sort(files)
 	return files, nil
 }
 
