@@ -50,12 +50,13 @@ func NewCmdConfigGet(f *cmdutils.Factory) *cobra.Command {
 		Use:   "get <key>",
 		Short: "Prints the value of a given configuration key.",
 		Long:  ``,
-		Example: `
-  $ glab config get editor
-  vim
-  $ glab config get glamour_style
-  notty
-`,
+		Example: heredoc.Doc(`
+  		$ glab config get editor
+  		> vim
+
+  		$ glab config get glamour_style
+  		> notty
+		`),
 		Args: cobra.ExactArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			cfg, err := f.Config()
@@ -92,11 +93,10 @@ func NewCmdConfigSet(f *cmdutils.Factory) *cobra.Command {
 Use 'glab config set --global' to set a global config.
 Specifying the '--hostname' flag also saves in the global configuration file.
 `,
-		Example: `
-  glab config set editor vim
-  glab config set token xxxxx -h gitlab.com
-  glab config set check_update false --global
-`,
+		Example: heredoc.Doc(`
+- glab config set editor vim
+- glab config set token xxxxx -h gitlab.com
+- glab config set check_update false --global`),
 		Args: cobra.ExactArgs(2),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			cfg, err := f.Config()
@@ -143,23 +143,24 @@ func NewCmdConfigEdit(f *cmdutils.Factory) *cobra.Command {
 		Short: "Opens the glab configuration file.",
 		Long: heredoc.Doc(`Opens the glab configuration file.
 The command uses the following order when choosing the editor to use:
+
 1. 'glab_editor' field in the configuration file
 2. 'VISUAL' environment variable
 3. 'EDITOR' environment variable
 `),
 		Example: heredoc.Doc(`
-			# Open the configuration file with the default editor
-			$ glab config edit
+			Open the configuration file with the default editor
+			- glab config edit
 
-			# Open the configuration file with vim
-			$ EDITOR=vim glab config edit
+			Open the configuration file with vim
+			- EDITOR=vim glab config edit
 
-			# Set vim to be used for all future 'glab config edit' invocations
-			$ glab config set editor vim
-			$ glab config edit
+			Set vim to be used for all future 'glab config edit' invocations
+			- glab config set editor vim
+			- glab config edit
 
-			# Open the local configuration file with the default editor
-			$ glab config edit -l
+			Open the local configuration file with the default editor
+			- glab config edit -l
 		`),
 		Args: cobra.NoArgs,
 		RunE: func(cmd *cobra.Command, args []string) error {
