@@ -7,20 +7,20 @@ import (
 	"gitlab.com/gitlab-org/cli/api"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/commands/issuable"
 	"gitlab.com/gitlab-org/cli/commands/issue/issueutils"
 )
 
 var closingMessage = map[issuable.IssueType]string{
-	issuable.TypeIssue:    "Closing Issue",
-	issuable.TypeIncident: "Resolving Incident",
+	issuable.TypeIssue:    "Closing issue",
+	issuable.TypeIncident: "Resolving incident",
 }
 
 var closedMessage = map[issuable.IssueType]string{
-	issuable.TypeIssue:    "Closed Issue",
-	issuable.TypeIncident: "Resolved Incident",
+	issuable.TypeIssue:    "Closed issue",
+	issuable.TypeIncident: "Resolved incident",
 }
 
 func NewCmdClose(f *cmdutils.Factory, issueType issuable.IssueType) *cobra.Command {
@@ -34,12 +34,12 @@ func NewCmdClose(f *cmdutils.Factory, issueType issuable.IssueType) *cobra.Comma
 
 	issueCloseCmd := &cobra.Command{
 		Use:     "close [<id> | <url>] [flags]",
-		Short:   fmt.Sprintf(`Close an %s`, issueType),
+		Short:   fmt.Sprintf(`Close an %s.`, issueType),
 		Long:    ``,
 		Aliases: aliases,
 		Example: heredoc.Doc(fmt.Sprintf(`
-			glab %[1]s close 123
-			glab %[1]s close https://gitlab.com/NAMESPACE/REPO/-/%s
+			$ glab %[1]s close 123
+			$ glab %[1]s close https://gitlab.com/NAMESPACE/REPO/-/%s
 		`, issueType, examplePath)),
 		Args: cobra.ExactArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) error {
