@@ -9,12 +9,12 @@ import (
 func NewCmdArtifact(f *cmdutils.Factory) *cobra.Command {
 	jobArtifactCmd := &cobra.Command{
 		Use:     "artifact <refName> <jobName> [flags]",
-		Short:   `Download all artifacts from the last pipeline`,
+		Short:   `Download all artifacts from the last pipeline.`,
 		Aliases: []string{"push"},
 		Example: heredoc.Doc(`
-	glab job artifact main build
-	glab job artifact main deploy --path="artifacts/"
-	`),
+			- glab job artifact main build
+			- glab job artifact main deploy --path="artifacts/"
+		`),
 		Long: ``,
 		Args: cobra.ExactArgs(2),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -33,6 +33,6 @@ func NewCmdArtifact(f *cmdutils.Factory) *cobra.Command {
 			return DownloadArtifacts(apiClient, repo, path, args[0], args[1])
 		},
 	}
-	jobArtifactCmd.Flags().StringP("path", "p", "./", "Path to download the artifact files")
+	jobArtifactCmd.Flags().StringP("path", "p", "./", "Path to download the artifact files.")
 	return jobArtifactCmd
 }
