@@ -18,14 +18,15 @@ func NewCmdRevoke(f *cmdutils.Factory) *cobra.Command {
 		Long:    ``,
 		Aliases: []string{"unapprove"},
 		Example: heredoc.Doc(`
-			$ glab mr revoke 123
-			$ glab mr unapprove 123
-			$ glab mr revoke branch
+			Revoke approval on a merge request
+			- glab mr revoke 123
+			- glab mr unapprove 123
+			- glab mr revoke branch
 
-			# Uses the checked-out branch
-			$ glab mr revoke
-
-			$ glab mr revoke 123 branch 456
+			Revoke approval on the currently checked out branch
+			- glab mr revoke
+			Revoke approval on merge request 123 on branch 456
+			- glab mr revoke 123 branch 456
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
