@@ -9,7 +9,7 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
@@ -43,13 +43,13 @@ func NewCmdDelete(f *cmdutils.Factory) *cobra.Command {
 			return deleteRun(opts)
 		},
 		Example: heredoc.Doc(`
-		# Delete a personal repository.
-		$ glab repo delete dotfiles
+			# Delete a personal repository.
+			$ glab repo delete dotfiles
 
-		# Delete a repository in a GitLab group, or another repository
-		# you have write access to:
-		$ glab repo delete mygroup/dotfiles
-		$ glab repo delete myorg/mynamespace/dotfiles
+			# Delete a repository in a GitLab group, or another repository
+			# you have write access to:
+			$ glab repo delete mygroup/dotfiles
+			$ glab repo delete myorg/mynamespace/dotfiles
 	  `),
 	}
 
