@@ -55,9 +55,9 @@ func NewCmdFork(f *cmdutils.Factory, runE func(*cmdutils.Factory) error) *cobra.
 		Use:   "fork <repo>",
 		Short: "Fork a GitLab repository.",
 		Example: heredoc.Doc(`
-			glab repo fork
-			glab repo fork namespace/repo
-			glab repo fork namespace/repo --clone
+			- glab repo fork
+			- glab repo fork namespace/repo
+			- glab repo fork namespace/repo --clone
 		`),
 		Args: cobra.MaximumNArgs(1),
 		RunE: func(cmd *cobra.Command, args []string) (err error) {
@@ -296,7 +296,7 @@ loop:
 
 			forkedRepoURL := glrepo.RemoteURL(forkedProject, protocol)
 
-			cloneDir, err := git.RunClone(forkedRepoURL, []string{})
+			cloneDir, err := git.RunClone(forkedRepoURL, "", []string{})
 			if err != nil {
 				return fmt.Errorf("failed to clone fork: %w", err)
 			}
