@@ -9,7 +9,7 @@ import (
 
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
@@ -42,19 +42,19 @@ func NewCmdView(f *cmdutils.Factory) *cobra.Command {
 		`),
 		Args: cobra.MaximumNArgs(1),
 		Example: heredoc.Doc(`
-			# View project information for the current directory.
-			# Must be a Git repository.
-			$ glab repo view
+			View project information for the current directory.
+			Must be a Git repository.
+			- glab repo view
 
-			# View project information of specified name.
-			$ glab repo view my-project
-			$ glab repo view user/repo
-			$ glab repo view group/namespace/repo
+			View project information of specified name.
+			- glab repo view my-project
+			- glab repo view user/repo
+			- glab repo view group/namespace/repo
 
-			# Specify repository by full [Git] URL.
-			$ glab repo view git@gitlab.com:user/repo.git
-			$ glab repo view https://gitlab.company.org/user/repo
-			$ glab repo view https://gitlab.company.org/user/repo.git
+			Specify repository by full [Git] URL.
+			- glab repo view git@gitlab.com:user/repo.git
+			- glab repo view https://gitlab.company.org/user/repo
+			- glab repo view https://gitlab.company.org/user/repo.git
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
@@ -257,7 +257,7 @@ func printProjectContentRaw(opts *ViewOptions, project *gitlab.Project, readme *
 
 	if readme != nil {
 		fmt.Fprintln(opts.IO.StdOut, "---")
-		fmt.Fprintf(opts.IO.StdOut, readme.Content)
+		fmt.Fprint(opts.IO.StdOut, readme.Content)
 		fmt.Fprintln(opts.IO.StdOut)
 	}
 }
