@@ -101,29 +101,29 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 		`, "`"),
 		Args: cmdutils.MinimumArgs(1, "no tag name provided."),
 		Example: heredoc.Docf(`
-			Create a release interactively
-			- glab release create v1.0.1
+			# Create a release interactively
+			$ glab release create v1.0.1
 
-			Create a release non-interactively by specifying a note
-			- glab release create v1.0.1 --notes "bugfix release"
+			# Create a release non-interactively by specifying a note
+			$ glab release create v1.0.1 --notes "bugfix release"
 
-			Use release notes from a file
-			- glab release create v1.0.1 -F changelog.md
+			# Use release notes from a file
+			$ glab release create v1.0.1 -F changelog.md
 
-			Upload a release asset with a display name (type will default to 'other')
-			- glab release create v1.0.1 '/path/to/asset.zip#My display label'
+			# Upload a release asset with a display name (type will default to 'other')
+			$ glab release create v1.0.1 '/path/to/asset.zip#My display label'
 
-			Upload a release asset with a display name and type
-			- glab release create v1.0.1 '/path/to/asset.png#My display label#image'
+			# Upload a release asset with a display name and type
+			$ glab release create v1.0.1 '/path/to/asset.png#My display label#image'
 
-			Upload all assets in a specified folder (types default to 'other')
-			- glab release create v1.0.1 ./dist/*
+			# Upload all assets in a specified folder (types default to 'other')
+			$ glab release create v1.0.1 ./dist/*
 
-			Upload all tarballs in a specified folder (types default to 'other')
-			- glab release create v1.0.1 ./dist/*.tar.gz
+			# Upload all tarballs in a specified folder (types default to 'other')
+			$ glab release create v1.0.1 ./dist/*.tar.gz
 
-			Create a release with assets specified as JSON object
-			- glab release create v1.0.1 --assets-links='
+			# Create a release with assets specified as JSON object
+			$ glab release create v1.0.1 --assets-links='
 			  [
 			    {
 			      "name": "Asset1",
@@ -150,7 +150,7 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			#   for components that bundle together multiple related files. For example,
 			#   %[1]stemplates/secret-detection/template.yml%[1]s.
 
-			- glab release create v1.0.1 --publish-to-catalog
+			$ glab release create v1.0.1 --publish-to-catalog
 		`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
@@ -612,7 +612,7 @@ func changelogForRange(refRange string) ([]logEntry, error) {
 	}
 
 	var entries []logEntry
-	for _, cb := range bytes.Split(b, []byte{'\000'}) {
+	for cb := range bytes.SplitSeq(b, []byte{'\000'}) {
 		c := strings.ReplaceAll(string(cb), "\r\n", "\n")
 		c = strings.TrimPrefix(c, "\n")
 		if c == "" {
