@@ -9,6 +9,7 @@ import (
 	stackSaveCmd "gitlab.com/gitlab-org/cli/commands/stack/save"
 	stackSwitchCmd "gitlab.com/gitlab-org/cli/commands/stack/switch"
 	stackSyncCmd "gitlab.com/gitlab-org/cli/commands/stack/sync"
+	"gitlab.com/gitlab-org/cli/pkg/git"
 	"gitlab.com/gitlab-org/cli/pkg/surveyext"
 	"gitlab.com/gitlab-org/cli/pkg/text"
 
@@ -28,27 +29,29 @@ func NewCmdStack(f *cmdutils.Factory) *cobra.Command {
 		Short: `Create, manage, and work with stacked diffs. (EXPERIMENTAL.)`,
 		Long:  `Stacked diffs are a way of creating small changes that build upon each other to ultimately deliver a feature. This kind of workflow can be used to accelerate development time by continuing to build upon your changes, while earlier changes in the stack are reviewed and updated based on feedback.` + "\n" + text.ExperimentalString,
 		Example: heredoc.Doc(`
-			glab stack create cool-new-feature
-			glab stack sync
+			$ glab stack create cool-new-feature
+			$ glab stack sync
 		`),
 		Aliases: []string{"stacks"},
 	}
 
+	var gr git.StandardGitCommand
+
 	cmdutils.EnableRepoOverride(stackCmd, f)
 	getTextFromEditor := wrappedEdit(f)
 
-	stackCmd.AddCommand(stackCreateCmd.NewCmdCreateStack(f))
-	stackCmd.AddCommand(stackSaveCmd.NewCmdSaveStack(f, getTextFromEditor))
-	stackCmd.AddCommand(stackSaveCmd.NewCmdAmendStack(f, getTextFromEditor))
-	stackCmd.AddCommand(stackSyncCmd.NewCmdSyncStack(f))
-	stackCmd.AddCommand(stackMoveCmd.NewCmdStackPrev(f))
-	stackCmd.AddCommand(stackMoveCmd.NewCmdStackNext(f))
-	stackCmd.AddCommand(stackMoveCmd.NewCmdStackFirst(f))
-	stackCmd.AddCommand(stackMoveCmd.NewCmdStackLast(f))
-	stackCmd.AddCommand(stackMoveCmd.NewCmdStackMove(f))
-	stackCmd.AddCommand(stackListCmd.NewCmdStackList(f))
-	stackCmd.AddCommand(stackReorderCmd.NewCmdReorderStack(f, getTextFromEditor))
-	stackCmd.AddCommand(stackSwitchCmd.NewCmdStackSwitch(f))
+	stackCmd.AddCommand(stackCreateCmd.NewCmdCreateStack(f, gr))
+	stackCmd.AddCommand(stackSaveCmd.NewCmdSaveStack(f, gr, getTextFromEditor))
+	stackCmd.AddCommand(stackSaveCmd.NewCmdAmendStack(f, gr, getTextFromEditor))
+	stackCmd.AddCommand(stackSyncCmd.NewCmdSyncStack(f, gr))
+	stackCmd.AddCommand(stackMoveCmd.NewCmdStackPrev(f, gr))
+	stackCmd.AddCommand(stackMoveCmd.NewCmdStackNext(f, gr))
+	stackCmd.AddCommand(stackMoveCmd.NewCmdStackFirst(f, gr))
+	stackCmd.AddCommand(stackMoveCmd.NewCmdStackLast(f, gr))
+	stackCmd.AddCommand(stackMoveCmd.NewCmdStackMove(f, gr))
+	stackCmd.AddCommand(stackListCmd.NewCmdStackList(f, gr))
+	stackCmd.AddCommand(stackReorderCmd.NewCmdReorderStack(f, gr, getTextFromEditor))
+	stackCmd.AddCommand(stackSwitchCmd.NewCmdStackSwitch(f, gr))
 
 	return stackCmd
 }
