@@ -68,7 +68,7 @@ func NewCmdSyncStack(f *cmdutils.Factory, gr git.GitRunner) *cobra.Command {
 1. Removes any branches that were already merged, or with a closed merge request.
 ` + text.ExperimentalString),
 		Example: heredoc.Doc(`
-			glab stack sync
+			$ glab stack sync
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			iostream.StartSpinner("Syncing")
